@@ -1,15 +1,16 @@
 # from utils import with_plural, to_regex
-from ..utils import with_plural, to_regex
+import re
+
+from ..utils import to_regex, with_plural
 
 # from data.ingredient_categories import fruits, vegetables, legumes, herbs
-from .ingredient_categories import fruits, vegetables, legumes, herbs
-
-# from data.meat import dictionary as meat_dict
-from .meat import dictionary as meat_dict
+from .ingredient_categories import VEG_FLOWER, is_fruit, vegetables
 
 # from data.ingredients import dictionary as ing_dict
 from .ingredients import dictionary as ing_dict
-import re
+
+# from data.meat import dictionary as meat_dict
+from .meat import dictionary as meat_dict
 
 proteins = list(meat_dict.keys())
 pasta = ing_dict["pasta"]
@@ -62,6 +63,10 @@ drink_list = with_plural(
         "cordial",
         "chai",
         "lassi",
+        "sangria",
+        "sangría",
+        "sangaree",
+        "sangarita",
         "aqua thunder",
         "limoncello",
         "tequini",
@@ -69,6 +74,9 @@ drink_list = with_plural(
         "the yellow jacket",
         "caribbean twist",
         "brazillian sunset",
+        "bora bora",
+        "blue hawaiian",
+        "blue lagoon",
     ]
 )
 soup_list = with_plural(
@@ -78,7 +86,13 @@ soup_list = with_plural(
         "chowder",
         "bouillabaisse",
         "gazpacho",
+        "gumbo",
         "bisque",
+        "borscht",
+        "bortsch",
+        "bortscht",
+        "bortsht",
+        "borsht",
         "bouillon",
         "broth",
         "consomme",
@@ -89,6 +103,9 @@ soup_list = with_plural(
         "skink",
         "laksa",
         "ramen",
+        "pho",
+        # "miso",
+        "mulligatawny",
         "goulash",
         "stew",
         "bourguignon",
@@ -104,16 +121,35 @@ niche_list = with_plural(
         "marinade",
         "dip",
         "jam",
+        "jelly",
         "queso",
+        "cheese",
         "jus",
         "dressing",
         "bread",
+        "cornbread",
         "spread",
         "preserve",
         "stock",
         "bouillon",
         "salsa",
         "gravy",
+        "catsup",
+        "ketchup",
+        "relish",
+        "chutney",
+        "pesto",
+        "syrup",
+        "salsa",
+        "sambal",
+        "mayonnaise",
+        "aioli",
+        "mustard",
+        "chimichurri",
+        "marmalade",
+        "marmelade",
+        # "bar",
+        "demi-glace",
     ]
 )
 dessert_list = with_plural(
@@ -169,7 +205,29 @@ sandwich_list = with_plural(
         "ciabatta",
     ]
 )
-exceptions = ["stock", "broth", "bouillon", "beefsteak"]
+exceptions = [
+    "stock",
+    "broth",
+    "bouillon",
+    "beefsteak",
+    r"icecream",
+    r"ice cream",
+    r"gelato",
+    r"sorbet",
+    r"sherbet",
+    r"frozen yogurt",
+    r"custard",
+    r"frozen dairy dessert",
+    r"frozen dessert",
+    r"ice milk",
+    r"soft serve",
+    r"ice pop",
+    r"ice lolly",
+    r"popsicle",
+    r"italian ice",
+    r"kulfi",
+    r"ice",
+]
 
 title_map = {
     "seafood": to_regex(["ceviche"]),
@@ -184,18 +242,16 @@ title_map = {
 
 ing_keys = proteins + ["pasta"]
 
-ing_map = {"spicy food": "spicy pepper"}
+ing_map = {"spicy food": "spicy pepper", "lean fish": "seafood"}
 
 root_map = {
     "sandwich": to_regex(sandwich_list),
     "vegetarian": to_regex(
-        with_plural(
-            vegetables + ["mushroom", "portobell", "brussels sprouts", "tofu", "beans"]
-        )
+        vegetables.VEG_DEFAULT
+        + [r"mushrooms?", r"portobells?", r"brussels? sprouts?", r"tofu", r"beans?"]
     ),
     "salad": to_regex(["(?<!fruit )salad"]),
     "pasta": to_regex(pasta + ["pasta", "alfredo"]),
-    # "dessert": to_regex(dessert_list),
     "niche": to_regex(niche_list),
     "soup": to_regex(soup_list),
     "drink": rf"{to_regex(drink_list)}$",
@@ -203,11 +259,23 @@ root_map = {
     "sushi": to_regex(
         ["nigiri", "sashimi", "chirashi", "oshizushi", "temaki", "uramaki", "sushi"]
     ),
+    "mushroom": to_regex(
+        [
+            "mushroom",
+            "portobello",
+            "portabella",
+            "crimini",
+            "shiitake",
+            "porcini",
+            "morel",
+            "chanterelle",
+        ]
+    ),
 }
 
 
-def is_dessert(parsedPhrases):
-    def is_dessert_ing(name, quantity):
+def is_dessert(title="", ingredients=[], phrases=[]):
+    def is_dessert_ing(name=""):
         key_list = [
             "syrup",
             "molasses",
@@ -215,13 +283,17 @@ def is_dessert(parsedPhrases):
             "caramel",
             r"nut$",
             "cocoa",
-            # "sugar",
+            "sugar",
             "milk",
             "cinnamon",
             "vanilla",
             "honey",
+            "mascarpone",
+            "ricotta",
         ]
-        if name == "sugar" and quantity and quantity > 50:
+        # if name == "sugar" and quantity and quantity > 50:
+        #     return True
+        if is_fruit(name):
             return True
 
         if re.search(rf"\b(?:{r'|'.join(key_list)})\b", name):
@@ -229,12 +301,26 @@ def is_dessert(parsedPhrases):
         return False
 
     def is_non_dessert_ing(name):
-        # herb_exceptions = r"(?:mint|basil|rosemary|thyme)"
-
         key_list = (
             # [h for h in herbs if not re.search(herb_exceptions, h)]
             proteins
-            + ["pepper", "garlic", "onion", "shallot", "spinach", "potato", "tofu"]
+            + VEG_FLOWER
+            + [
+                "pepper",
+                "garlic",
+                "onion",
+                "shallot",
+                "spinach",
+                "mustard",
+                "cilantro",
+                "coriander",
+                "cauliflower",
+                "cumin",
+                "sauerkraut",
+                "ketchup",
+                "horseradish",
+                "potato",  # temporary solution
+            ]
             + [
                 "monterey jack cheese",
                 "mexican cheese",
@@ -242,23 +328,22 @@ def is_dessert(parsedPhrases):
                 "mozzarella cheese",
                 "pecorino cheese",
                 "gruyere cheese",
-                "cottage cheese",
                 "pepper jack cheese",
                 "cheddar cheese",
                 "parmesan cheese",
+                "halloumi cheese",
+                "paneer cheese",
+                "brie cheese",
             ]
         )
         if re.search(rf"\b(?:{r'|'.join(key_list)})\b", name):
             return True
         return False
 
-    if all(
-        not ing or not is_dessert_ing(ing["simple"], ing["quantity"])
-        for ing in parsedPhrases
-    ):
+    if all(not ing or not is_dessert_ing(ing) for ing in ingredients):
         return False
 
-    if any(ing and is_non_dessert_ing(ing["simple"]) for ing in parsedPhrases):
+    if any(ing and is_non_dessert_ing(ing) for ing in ingredients):
         return False
 
     return True
