@@ -1,4 +1,6 @@
-flatten = lambda l: [item for sublist in l for item in sublist]
+def flatten(l):
+    return [item for sublist in l for item in sublist]
+
 
 u_volume_metric = {
     "cl": [r"cls?", r"centilit(?:er|re)s?"],
@@ -94,7 +96,6 @@ u_misc = {
     "sheet": [r"sheets?"],
     "leaf": [r"lea(?:f|ves)"],
     "bag": [r"bags?"],
-    "head": [r"heads?"],
     "carton": [r"cartons?"],
     "stick": [r"sticks?"],
     "link": [r"links?"],
@@ -102,7 +103,6 @@ u_misc = {
     "cube": [r"cubes?"],
     "recipe": [r"recipes?"],
     "glass": [r"glass(?:es)?"],
-    "handful": [r"handfuls?"],
     "splash": [r"splash(?:es)?"],
     # 'half': [r'(?<!half-and-)hal(?:f|ves)(?!-and-half)'],
     "pod": [r"pods?"],
